EM algorithm - Kerasy Documentation
Author: Shuto
Description: Brief explanation of EM algorithm and introduction of modules that can be used in Kerasy

### EM algorithm

- 2019-11-28(木)
- ML/EM.py

Notebook

Example Notebook: Kerasy.examples.EM.ipynb

## EM algorithm

    class kerasy.ML.EM.BaseEMmodel(K, random_state=None)

## KMeans

    class kerasy.ML.EM.KMeans(K, random_state=None)

## Gaussian Mixture model

    class kerasy.ML.EM.MixedGaussian(K, random_state=None)

Reference

- Pattern Recognition and Machine Learning by Christopher Bishop

« Previous Next »